# Wyzeapy: Python wrapper around the Wyze App APIs

This library is primarily designed to be used in the [ha-wyzeapi](https://github.com/JoshuaMulliken/ha-wyzeapi) Home Assistant integration. If you find it useful in another application please let me know so that I can notify you of any breaking changes.

## Usage

For now please look at the implementation of ha-wyzeapi. I do not have the time to write significant documentation until both of these projects are at a feature complete and stable place.

## Code Scanning

Analysis is run through: [sonarcloud](https://sonarcloud.io/dashboard?id=JoshuaMulliken_wyzeapy)
